@@ -6,15 +6,9 @@ test_that("canDownloadFiles", {
   load(trdata)
   load(tldata)
   dllist <- assign_directory(test_dllist, "myapp")
-  with_mock(
-    `httr::GET` = function(...){
-      test_llres
-    },
-    `base::dir.create` = function(...){TRUE},
-    dlfiles <- download_files(dllist)
-  )
-  test_res <- do.call(rbind.data.frame, dlfiles)
-  expect_true(all(test_res[["processed"]]))
+  
+  dlfiles <- download_files(dllist)
+  expect_true(all(dlfiles[["processed"]]))
 })
 
 test_that("canReturnEmptyDFWhenEmptyDownloadFiles", {
@@ -24,13 +18,8 @@ test_that("canReturnEmptyDFWhenEmptyDownloadFiles", {
   load(tldata)
   dllist <- assign_directory(test_dllist, "myapp")
   dllist <- lapply(dllist, function(x){x[["exists"]] <- TRUE; x})
-  with_mock(
-    `httr::GET` = function(...){
-      test_llres
-    },
-    `base::dir.create` = function(...){TRUE},
-    dlfiles <- download_files(dllist)
-  )
+  
+  dlfiles <- download_files(dllist)
   exout <- data.frame(platform = character(), file = character(),
                       processed = logical(), stringsAsFactors = FALSE)
   expect_identical(dlfiles, exout)
